@@ -22,6 +22,8 @@ class BaseClientParameter:
         'AMQP_BROKER_ID',
         'AWS_REGION',
         'AMQP_HOST',
+        'AMQP_SOCKET_TIMEOUT',
+        'AMQP_HEARTBEAT'
     ]
 
     def __init__(self) -> None:
@@ -42,8 +44,17 @@ class BaseClientParameter:
         if self.amqp_broker_id is not None and self.aws_region is None:
             raise BaseClientException('AWS_REGION')
 
+        if self.amqp_broker_id is None and self.amqp_socket_timeout is None:
+            self.amqp_socket_timeout = 5
+
+        if self.amqp_broker_id is None and self.amqp_heartbeat is None:
+            self.amqp_heartbeat = False
+
 class BaseClient:
     def __init__(self) -> None:
+        self.to_connect()
+
+    def to_connect(self) -> None:
         self.parameters = BaseClientParameter()
 
         if self.parameters.amqp_broker_id is None:
@@ -57,7 +68,7 @@ class BaseClient:
             raise QueueNotFoundException(queue)
         return queue
 
-    def _create_connection_to_local_instance(self, socket_timeout:int=5, heartbeat:bool=False) -> None:
+    def _create_connection_to_local_instance(self) -> None:
         parameters = pika.URLParameters(
             'amqp://{AMQP_USER}:{AMQP_PASSWORD}@{AMQP_HOST}'.format(
                 AMQP_USER=self.parameters.amqp_user,
@@ -65,8 +76,8 @@ class BaseClient:
                 AMQP_HOST=self.parameters.amqp_host,
             )
         )
-        parameters.socket_timeout = socket_timeout
-        parameters.heartbeat = heartbeat
+        parameters.socket_timeout = self.parameters.amqp_socket_timeout
+        parameters.heartbeat = self.parameters.amqp_heartbeat
 
         self.connection = pika.BlockingConnection(parameters)
         self.channel = self.connection.channel()
@@ -85,6 +96,8 @@ class BaseClient:
             )
         )
         parameters.ssl_options = pika.SSLOptions(context=ssl_context)
+        parameters.socket_timeout = self.parameters.amqp_socket_timeout
+        parameters.heartbeat = self.parameters.amqp_heartbeat
 
         self.connection = pika.BlockingConnection(parameters)
         self.channel = self.connection.channel()
\ No newline at end of file
