@@ -88,11 +88,11 @@ class FaceDetectionStub(Stub):
             content={}
         )
 
-    def to_recognize(self, detected_object_class_id:int, image_key:str) -> None:
+    def to_recognize(self, detected_object_id:int, image_key:str) -> None:
         self._send(
             primitive='to_recognize',  
             content={
-                'detected_object_class_id': detected_object_class_id,
+                'detected_object_id': detected_object_id,
                 'image_key': image_key
             }
         )
\ No newline at end of file
